@@ -1,17 +1,18 @@
 
-plotC <- function (model, columns = NULL) 
+plotC <- function (object, columns = NULL) 
 {
-     fn <- paste(model, "_C.csv", sep = "")
-     C <- read.table(fn, sep = ",", header = TRUE)
+     if (is.null(object[["C"]])) stop("No random parameters to plot.")
+  
+     C <- object[["C"]]
      gNIV <- ncol(C) - 2
      numIDs <- nrow(C)
      graphics.off()
      par(ask = TRUE)
-     if (is.null(columns)) {
-          columns <- 1:gNIV + 2
-     }
+     
+     if (is.null(columns)) columns <- 1:gNIV + 2
+     
      for (i in columns) {
-          plot(density(C[, i]), type = "l", main = paste(names(C)[i], "\n",
+          plot(density(C[, i]), type = "l", main = paste(colnames(C)[i], "\n",
                sum(C[,i] >= 0), " (", round(sum(C[,i] >= 0) / length(C[,i]) * 100, 1),
                "%) >= 0", sep = ""), 
                xlab = "Utility", ylab = "Density")
